Think harder to complete these tasks:
1. Read artifacts/backlog/active.md
2. Understand the [x] complete and [ ] incomplete tasks
3. Understand the current state of the project
4. Develop the next single [ ] incomplete task in sequence
5. When development is done mark the task [x] complete
